
# THIS FILE IS GENERATED FROM SigProfilerAssignment SETUP.PY
short_version = '0.0.22'
version = '0.0.22'
Update = 'Resolve issue with ID decomposition plots, JOBMETADATA upgrade, add DBS tests.'

    
    